<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>ArrowToolOptionsBox</name>
    <message>
        <source>Pick:</source>
        <translation>Seleziona Automaticamente:</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>Z:</source>
        <translation>Z:</translation>
    </message>
    <message>
        <source>SO:</source>
        <translation>OS:</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Ruotazione</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Scala</translation>
    </message>
    <message>
        <source>Global:</source>
        <translation>Globale:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>O:</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Maintain:</source>
        <translation>Mantieni:</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>Inclina</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Centro</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="vanished">Blocca</translation>
    </message>
    <message>
        <source>(</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation type="unfinished">Posizione del Centro</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip Object Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip Object Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Object Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Object Right</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrushTool</name>
    <message>
        <source>Thickness</source>
        <translation type="vanished">Spessore</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation type="vanished">Durezza:</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation type="vanished">Accuratezza:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation type="vanished">Selettivo</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation type="vanished">Pennello Predefinito:</translation>
    </message>
    <message>
        <source>Break Sharp Angles</source>
        <translation type="vanished">Spezza negli Angoli Acuti</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation type="vanished">Modalità Matita</translation>
    </message>
    <message>
        <source>Pressure Sensitivity</source>
        <translation type="vanished">Sensibilità alla Pressione</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation type="vanished">Estremo</translation>
    </message>
    <message>
        <source>Join</source>
        <translation type="vanished">Angolo</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation type="vanished">Smusso:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="obsolete">Calamita</translation>
    </message>
</context>
<context>
    <name>BrushToolOptionsBox</name>
    <message>
        <source>Preset Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annullare</translation>
    </message>
</context>
<context>
    <name>ControlPointEditorTool</name>
    <message>
        <source>Auto Select Drawing</source>
        <translation>Selezione Automatica dei Disegni</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="unfinished">Calamita</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ControlPointSelection</name>
    <message>
        <source>Set Linear Control Point</source>
        <translation>Imposta un punto di Controllo Lineare</translation>
    </message>
    <message>
        <source>Set Nonlinear Control Point</source>
        <translation>Imposta un punto di Controllo Non Lineare</translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTool</name>
    <message>
        <source>Scale Constraint:</source>
        <translation>Costrizione della Scala:</translation>
    </message>
    <message>
        <source>Auto Select Column</source>
        <translation>Selezione Automatica della Colonna</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>Chiave Globale</translation>
    </message>
    <message>
        <source>Lock Center X</source>
        <translation>Blocca il Centro X</translation>
    </message>
    <message>
        <source>Lock Center Y</source>
        <translation>Blocca il Centro Y</translation>
    </message>
    <message>
        <source>Lock Position X</source>
        <translation>Blocca la Posizione X</translation>
    </message>
    <message>
        <source>Lock Position Y</source>
        <translation>Blocca la Posizione Y</translation>
    </message>
    <message>
        <source>Lock Rotation</source>
        <translation>Blocca la Rotazione</translation>
    </message>
    <message>
        <source>Lock Shear H</source>
        <translation>Blocca l&apos;Inclinazione O</translation>
    </message>
    <message>
        <source>Lock Shear V</source>
        <translation>Blocca l&apos;Inclinazione V</translation>
    </message>
    <message>
        <source>Lock Scale H</source>
        <translation>Blocca la Scalatura O</translation>
    </message>
    <message>
        <source>Lock Scale V</source>
        <translation>Blocca la Scalatura V</translation>
    </message>
    <message>
        <source>Lock Global Scale</source>
        <translation>Blocca la Scalatura Globale</translation>
    </message>
    <message>
        <source>X and Y Positions</source>
        <translation>Posizioni X e Y</translation>
    </message>
    <message>
        <source>Z Position</source>
        <translation>Posizione Z</translation>
    </message>
    <message>
        <source>SO</source>
        <translation>OS</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Rotazione</translation>
    </message>
    <message>
        <source>Global Scale</source>
        <translation>Scala Globale</translation>
    </message>
    <message>
        <source>Horizontal and Vertical Scale</source>
        <translation>Scala Orizzontale e Verticale</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>Inclinazione</translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation>Posizione del Centro</translation>
    </message>
    <message>
        <source>Active Axis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A/R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mass</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pegbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="unfinished">Posizione</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished">Scala</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="unfinished">Centro</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EraserTool</name>
    <message>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Durezza:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modalità:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Selettivo</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverti</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>Intervallo di Fotogrammi</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>Modalità Matita</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segment</source>
        <translation type="unfinished">Segmento</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease In/Out</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FillTool</name>
    <message>
        <source>Frame Range</source>
        <translation>Intervallo di Fotogrammi</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Selettivo</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modalità:</translation>
    </message>
    <message>
        <source>Onion Skin</source>
        <translation>Onion Skin</translation>
    </message>
    <message>
        <source>Fill Depth</source>
        <translation>Profondità di Riempimento</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>Segmento</translation>
    </message>
    <message>
        <source>Autopaint Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Gap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick+Freehand</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FingerTool</name>
    <message>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invert</source>
        <translation type="unfinished">Inverti</translation>
    </message>
</context>
<context>
    <name>FullColorBrushTool</name>
    <message>
        <source>Thickness</source>
        <translation type="vanished">Spessore</translation>
    </message>
    <message>
        <source>Pressure Sensitivity</source>
        <translation type="vanished">Sensibilità alla Pressione</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation type="vanished">Opacità:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Durezza:</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>Impostazioni Predefinite:</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullColorEraserTool</name>
    <message>
        <source>Size:</source>
        <translation>Dimensioni:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacità:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Durezza:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverti</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>Intervallo di Fotogrammi</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullColorFillTool</name>
    <message>
        <source>Fill Depth</source>
        <translation type="unfinished">Profondità di Riempimento</translation>
    </message>
</context>
<context>
    <name>HandToolOptionsBox</name>
    <message>
        <source>Reset Position</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HookTool</name>
    <message>
        <source>Snap</source>
        <translation>Calamita</translation>
    </message>
</context>
<context>
    <name>MagnetTool</name>
    <message>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
</context>
<context>
    <name>PaintBrushTool</name>
    <message>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modalità:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Selettivo</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PinchTool</name>
    <message>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <source>Corner:</source>
        <translation>Angolo:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
</context>
<context>
    <name>PlasticTool</name>
    <message>
        <source>Build Skeleton</source>
        <translation>Costruire Scheletro</translation>
    </message>
    <message>
        <source>Paint Rigid</source>
        <translation>Disegnare Rigidità</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation>Animare</translation>
    </message>
    <message>
        <source>Rigid</source>
        <translation>Rigido</translation>
    </message>
    <message>
        <source>Flex</source>
        <translation>Flessibile</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modalità:</translation>
    </message>
    <message>
        <source>Vertex Name:</source>
        <translation>Nome Vertice</translation>
    </message>
    <message>
        <source>Allow Stretching</source>
        <translation>Permettere Estensione</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Spessore</translation>
    </message>
    <message>
        <source>Keep Distance</source>
        <translation>Mantenere Distanza</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>Chiave Globale</translation>
    </message>
    <message>
        <source>A group of skeletons already exists for current column. Replacing it will also substitute any existing vertex animation.

Do you want to continue?</source>
        <translation>Sulla colonna corrente esiste già un gruppo di scheletri, rimpiazzandolo tutte le animazioni dei vertici saranno sostituite.
Continuare?</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annullare</translation>
    </message>
    <message>
        <source>Copy Skeleton</source>
        <translation>Copiare Scheletro</translation>
    </message>
    <message>
        <source>Paste Skeleton</source>
        <translation>Incollare Scheletro</translation>
    </message>
    <message>
        <source>Delete Vertex</source>
        <translation>Cancellare Vertice</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Impostare Chiave</translation>
    </message>
    <message>
        <source>Set Rest Key</source>
        <translation>Impostare Chiave di Riposo</translation>
    </message>
    <message>
        <source>Show Mesh</source>
        <translation>Visualizzare Mesh</translation>
    </message>
    <message>
        <source>Show Rigidity</source>
        <translation>Visualizzare Rigidità</translation>
    </message>
    <message>
        <source>Show SO</source>
        <translation>Visualizzare Ordine Sovrapposizione</translation>
    </message>
    <message>
        <source>Show Skeleton Onion Skin</source>
        <translation>Visualizzare Scheletro in Onion Skin</translation>
    </message>
    <message>
        <source>The previous vertex name will be discarded, and all associated keys will be lost.

Do you want to proceed?</source>
        <translation>Il nome esistente del vertice sarà eliminato e le chiavi associate andranno perse.

Procedere?</translation>
    </message>
    <message>
        <source>Set Global Key</source>
        <translation>Imposta Chiave Globale</translation>
    </message>
    <message>
        <source>Set Global Rest Key</source>
        <translation>Imposta Chiave Globale a Riposo</translation>
    </message>
    <message>
        <source>Edit Mesh</source>
        <translation></translation>
    </message>
    <message>
        <source>Snap To Mesh</source>
        <translation></translation>
    </message>
    <message>
        <source>Angle Bounds</source>
        <translation></translation>
    </message>
    <message>
        <source>Swap Edge</source>
        <translation></translation>
    </message>
    <message>
        <source>Collapse Edge</source>
        <translation></translation>
    </message>
    <message>
        <source>Split Edge</source>
        <translation></translation>
    </message>
    <message>
        <source>Cut Mesh</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PlasticToolOptionsBox</name>
    <message>
        <source>Create Mesh</source>
        <translation>Creare Mesh</translation>
    </message>
    <message>
        <source>Skeleton:</source>
        <translation>Scheletro:</translation>
    </message>
    <message>
        <source>SO</source>
        <translation>OS</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Angolo</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distanza</translation>
    </message>
</context>
<context>
    <name>PrimitiveParam</name>
    <message>
        <source>Shape:</source>
        <translation>Forma:</translation>
    </message>
    <message>
        <source>Thickness:</source>
        <translation>Spessore:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacità:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Durezza:</translation>
    </message>
    <message>
        <source>Polygon Sides:</source>
        <translation>Lati del Poligono:</translation>
    </message>
    <message>
        <source>Auto Group</source>
        <translation>Raggruppa Automaticamente</translation>
    </message>
    <message>
        <source>Auto Fill</source>
        <translation>Riempimento Automatico</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Selettivo</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>Modalità Matita</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>Estremo</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Angolo</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>Smusso:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="unfinished">Calamita</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Circle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MultiArc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smooth</source>
        <translation type="unfinished">Liscio</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PumpTool</name>
    <message>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>Precisione:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Min:</source>
        <translation>Min:</translation>
    </message>
    <message>
        <source>Max:</source>
        <translation>Max:</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>The copied selection cannot be pasted in the current drawing.</source>
        <translation>La selezione copiata non può essere incollata nel disegno corrente.</translation>
    </message>
    <message>
        <source>The current column is locked.</source>
        <translation>La colonna corrente è bloccata.</translation>
    </message>
    <message>
        <source>The current column is not visible in Camera Stand.</source>
        <translation type="vanished">La colonna corrente non è visibile in Camera Stand.</translation>
    </message>
    <message>
        <source>It is not possible to edit the audio column.</source>
        <translation>Non è possibile modificare l&apos; audio della colonna.</translation>
    </message>
    <message>
        <source>It is not possible to edit the Magpie column.</source>
        <translation type="vanished">Non è possibile modificare la colonna Magpie.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Level column.</source>
        <translation>Lo strumento corrente non può essere utilizzato su una colonna Livello.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh column.</source>
        <translation>Lo strumento corrente non può essere utilizzato su una colonna Mesh.</translation>
    </message>
    <message>
        <source>The current tool cannot be used in Level Strip mode.</source>
        <translation>Lo strumento corrente non può essere utilizzato in modalità Level Strip.</translation>
    </message>
    <message>
        <source>The current tool cannot be used to edit a motion path.</source>
        <translation>Lo strumento corrente non può essere utilizzato per modificare una traiettoria.</translation>
    </message>
    <message>
        <source>The current level is not editable.</source>
        <translation>Il livello corrente non è editabile.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Vector Level.</source>
        <translation>Lo strumento corrente non può essere utilizzato su un livello vettoriale.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Toonz Level.</source>
        <translation>Lo strumento corrente non può essere utilizzato su un livello Toonz Raster.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Raster Level.</source>
        <translation>Lo strumento corrente non può essere utilizzato su un livello Raster.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh Level.</source>
        <translation>Lo strumento corrente non può essere utilizzato su un livello Mesh.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a mesh-deformed level</source>
        <translation>Lo strumento corrente non può essere utilizzato su un livello deformato da una Mesh.</translation>
    </message>
    <message>
        <source>The current frame is locked: any editing is forbidden.</source>
        <translation>Il fotogramma corrente è bloccato: è vietato ogni tipo di modifica.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annullare</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RGB Picker (R%1, G%2, B%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Gadget  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1   Level : %2  Frame : %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Stroke Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Spline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deform Raster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transform Raster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Save Box : (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The current column is hidden.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note columns can only be edited in the xsheet or timeline.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to Backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be updated. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be deleted. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be pasted. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be grouped. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be entered. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be ungrouped. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be moved. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snap At Intersection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RGBPickerTool</name>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RGBPickerToolOptionsBox</name>
    <message>
        <source>Pick Screen</source>
        <translation>Pick Screen</translation>
    </message>
</context>
<context>
    <name>RasterSelectionTool</name>
    <message>
        <source>Modify Savebox</source>
        <translation>Modificare Savebox</translation>
    </message>
    <message>
        <source>No Antialiasing</source>
        <translation>Nessun Antialiasing</translation>
    </message>
</context>
<context>
    <name>RasterTapeTool</name>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translation>Distanza:</translation>
    </message>
    <message>
        <source>Style Index:</source>
        <translation>Indice dello Stile:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacità:</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>Intervallo di Fotogrammi</translation>
    </message>
    <message>
        <source>Angle:</source>
        <translation>Angolo:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RotateTool</name>
    <message>
        <source>Rotate On Camera Center</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RotateToolOptionsBox</name>
    <message>
        <source>Reset Rotation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RulerToolOptionsBox</name>
    <message>
        <source>X:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished">X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished">Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>H:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished">O:</translation>
    </message>
    <message>
        <source>A:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>L:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectionToolOptionsBox</name>
    <message>
        <source>H:</source>
        <translation>O:</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>V</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Rotazione</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Spessore</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Vincola</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished">Scala</translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="unfinished">Posizione</translation>
    </message>
    <message>
        <source>Flip Selection Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip Selection Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Selection Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Selection Right</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShiftTraceToolOptionBox</name>
    <message>
        <source>Reset Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Following</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Following Drawing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SkeletonTool</name>
    <message>
        <source>Show Only Active Skeleton</source>
        <translation>Mostra solo lo Scheletro Attivo</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>Chiave Globale</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modalità:</translation>
    </message>
    <message>
        <source>Reset Pinned Center</source>
        <translation>Ripristina il centro bloccato</translation>
    </message>
    <message>
        <source>Build Skeleton</source>
        <translation type="unfinished">Costruire Scheletro</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation type="unfinished">Animare</translation>
    </message>
    <message>
        <source>Inverse Kinematics</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StylePickerTool</name>
    <message>
        <source>No current level.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current level has no available palette.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette must have more than one palette to be organized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation type="unfinished">Modalità:</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Organize Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StylePickerToolOptionsBox</name>
    <message>
        <source>With this option being activated, the picked style will be
moved to the end of the first page of the palette.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToonzRasterBrushTool</name>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation type="unfinished">Durezza:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw Order:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Over All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Under All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToonzVectorBrushTool</name>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Break</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cap</source>
        <translation type="unfinished">Estremo</translation>
    </message>
    <message>
        <source>Join</source>
        <translation type="unfinished">Angolo</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation type="unfinished">Smusso:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="unfinished">Calamita</translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Linear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In&amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrackerTool</name>
    <message>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altezza:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
</context>
<context>
    <name>TypeTool</name>
    <message>
        <source>Font:</source>
        <translation>Carattere:</translation>
    </message>
    <message>
        <source>Style:</source>
        <translation>Stile:</translation>
    </message>
    <message>
        <source>Vertical Orientation</source>
        <translation>Orientazione Verticale</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
</context>
<context>
    <name>VectorSelectionTool</name>
    <message>
        <source>Mode:</source>
        <translation>Modalità:</translation>
    </message>
    <message>
        <source>Preserve Thickness</source>
        <translation>Mantieni costante lo Spessore</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>Estremo</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Angolo</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>Smusso:</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Whole Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same Style on Selected Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same Style on Whole Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boundary Strokes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boundaries on Selected Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boundaries on Whole Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include Intersection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VectorTapeTool</name>
    <message>
        <source>Smooth</source>
        <translation>Liscio</translation>
    </message>
    <message>
        <source>Join Vectors</source>
        <translation>Unisci i Vettori</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation></translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Modalità:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Sali di Un Livello</translation>
    </message>
    <message>
        <source>Endpoint to Endpoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Endpoint to Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line to Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomToolOptionsBox</name>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
